==> org.Dm.eg.db_2.5.0.tar.gz: org.Dm.eg.db/man/org.Dm.egMAP.Rd <==
\name{org.Dm.egMAP}
\alias{org.Dm.egMAP}
\alias{org.Dm.egMAP2EG}
\title{Map between Entrez Gene Identifiers and cytogenetic maps/bands}
\description{
   org.Dm.egMAP is an R object that provides mappings between
   entrez gene identifiers and cytoband locations.
}
\details{
  Each entrez gene identifier is mapped to a vector of cytoband locations. The
  vector length may be one or longer, if there are multiple reported
  chromosomal locations for a given gene. An \code{NA} is reported for
  any entrez gene identifiers that cannot be mapped to a cytoband at this time.
  
  The physical location of each band on a chromosome can be obtained
  from another object named "organism"CYTOLOC in a separate data
  package for human(humanCHRLOC), mouse(mouseCHRLOC), and rat(ratCHRLOC).  
  
  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2011-Mar16

}
\references{
  \url{http://www.ncbi.nlm.nih.gov}
}
\examples{
        x <- org.Dm.egMAP
        # Get the entrez gene identifiers that are mapped to any cytoband
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the ids for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
        #For the reverse map org.Dm.egMAP2EG
        x <- org.Dm.egMAP2EG
        # Get the cytobands that are mapped to any entrez gene id
        mapped_bands <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_bands])
        if(length(xx) > 0) {
          # Get the bands for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}
\keyword{datasets}

==> org.Dm.eg.db_2.6.4.tar.gz: org.Dm.eg.db/man/org.Dm.egMAP.Rd <==
\name{org.Dm.egMAP}
\alias{org.Dm.egMAP}
\alias{org.Dm.egMAP2EG}
\title{Map between Entrez Gene Identifiers and cytogenetic maps/bands}
\description{
   org.Dm.egMAP is an R object that provides mappings between
   entrez gene identifiers and cytoband locations.
}
\details{
  Each entrez gene identifier is mapped to a vector of cytoband locations. The
  vector length may be one or longer, if there are multiple reported
  chromosomal locations for a given gene. An \code{NA} is reported for
  any entrez gene identifiers that cannot be mapped to a cytoband at this time.
  
  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2011-Sep14

}
\references{
  \url{http://www.ncbi.nlm.nih.gov}
}
\examples{
        x <- org.Dm.egMAP
        # Get the entrez gene identifiers that are mapped to any cytoband
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the ids for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
        #For the reverse map org.Dm.egMAP2EG
        x <- org.Dm.egMAP2EG
        # Get the cytobands that are mapped to any entrez gene id
        mapped_bands <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_bands])
        if(length(xx) > 0) {
          # Get the bands for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}
\keyword{datasets}
